@@ -69,12 +69,15 @@
 #'  \item{\code{getCategories()}}{
 #'    Retrieves the list of categories available in Geonetwork
 #'  }
-#'  \item{\code{insertMetadata(xml, file, geometa, group, category, stylesheet, validate, geometa_validate, geometa_inspire)}}{
+#'  \item{\code{insertMetadata(xml, file, geometa, group, category, stylesheet, validate, geometa_validate, 
+#'                             geometa_inspire, geometa_inspireValidator)}}{
 #'    Inserts a metadata by file, XML object or \pkg{geometa} object of class
 #'    \code{ISOMetadata} or \code{ISOFeatureCatalogue}. If successful, returns the Geonetwork
 #'    metadata internal identifier (integer). Extra parameters \code{geometa_validate} (TRUE 
 #'    by default) and \code{geometa_inspire} (FALSE by default) can be used with geometa objects 
-#'    for perform ISO and INSPIRE validation respectively.
+#'    for perform ISO and INSPIRE validation respectively. In that case on object of class 
+#'    \code{geometa::INSPIREMetadataValidator}, with a proper user API key, should be specified as
+#'    \code{geometa_inspireValidator} argument. 
 #'  }
 #'  \item{\code{setPrivConfiguration(id, config)}}{
 #'    Set the privilege configuration for a metadata. 'id' is the metadata integer id.
@@ -99,11 +102,14 @@
 #'  \item{\code{getInfoByUUID(uuid)}}{
 #'    Get a metadata Info by UUID. Returns an XML document object
 #'  }
-#'  \item{\code{updateMetadata(id, xml, file, geometa, geometa_validate, geometa_inspire)}}{
+#'  \item{\code{updateMetadata(id, xml, file, geometa, geometa_validate, 
+#'                             geometa_inspire, geometa_inspireValidator)}}{
 #'    Updates a metadata by file, XML object or \pkg{geometa} object of class
 #'    'ISOMetadata' or 'ISOFeatureCatalogue'. Extra parameters \code{geometa_validate} (TRUE 
 #'    by default) and \code{geometa_inspire} (FALSE by default) can be used with geometa objects 
-#'    for perform ISO and INSPIRE validation respectively.
+#'    for perform ISO and INSPIRE validation respectively. In that case on object of class 
+#'    \code{geometa::INSPIREMetadataValidator}, with a proper user API key, should be specified as
+#'    \code{geometa_inspireValidator} argument. 
 #'  }
 #'  \item{\code{deleteMetadata(id)}}{
 #'    Deletes a metadata
@@ -318,7 +324,7 @@ GNLegacyAPIManager <- R6Class("GNLegacyAPIManager",
      #---------------------------------------------------------------------------
      insertMetadata = function(xml = NULL, file = NULL, geometa = NULL, group,
                                category = NULL, stylesheet = NULL, validate = FALSE,
-                               geometa_validate = TRUE, geometa_inspire = FALSE){
+                               geometa_validate = TRUE, geometa_inspire = FALSE, geometa_inspireValidator = NULL){
        self$INFO("Inserting metadata ...")
        out <- NULL
        data <- NULL
@@ -337,7 +343,8 @@ GNLegacyAPIManager <- R6Class("GNLegacyAPIManager",
          if(!is(geometa, "ISOMetadata") & !is(geometa, "ISOFeatureCatalogue")){
            stop("Object 'geometa' should be of class 'ISOMetadata' or 'ISOFeatureCatalogue")
          }
-         data <- geometa$encode(validate = geometa_validate, inspire = geometa_inspire)
+         data <- geometa$encode(validate = geometa_validate, 
+                                inspire = geometa_inspire, inspireValidator = geometa_inspireValidator)
        }
        
        if(is.null(data)){
@@ -504,7 +511,7 @@ GNLegacyAPIManager <- R6Class("GNLegacyAPIManager",
      #updateMetadata
      #---------------------------------------------------------------------------
      updateMetadata = function(id, xml = NULL, file = NULL, geometa = NULL,
-                               geometa_validate = TRUE, geometa_inspire = FALSE){
+                               geometa_validate = TRUE, geometa_inspire = FALSE, geometa_inspireValidator = NULL){
        
        self$INFO(sprintf("Updating metadata id = %s ...", id))
        out <- NULL
@@ -524,7 +531,8 @@ GNLegacyAPIManager <- R6Class("GNLegacyAPIManager",
          if(!is(geometa, "ISOMetadata") & !is(geometa, "ISOFeatureCatalogue")){
            stop("Object 'geometa' should be of class 'ISOMetadata' or 'ISOFeatureCatalogue")
          }
-         data <- geometa$encode(validate = geometa_validate, inspire = geometa_inspire)
+         data <- geometa$encode(validate = geometa_validate, 
+                                inspire = geometa_inspire, inspireValidator = geometa_inspireValidator)
        }
        
        if(is.null(data)){
